﻿namespace U2UConsult.Keyboard.Sample
{
    using System.Threading.Tasks;
    using Windows.UI.ViewManagement;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;
    using Windows.UI.Xaml.Input;

    // The touch keyboard white paper:
    // http://msdn.microsoft.com/en-us/library/windows/apps/hh465404.aspx
    // Quote: "Applications cannot programmatically invoke the touch keyboard via manipulation of focus."

    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();

            this.Loaded += MainPage_Loaded;

            var inputPane = InputPane.GetForCurrentView();
            inputPane.Showing += InputPane_Showing;
            inputPane.Hiding += InputPane_Hiding;
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            // Gives focus correctly, but does not open the soft keyboard.
            this.TrappedTextBox.Focus(FocusState.Programmatic);
        }

        protected override void OnNavigatedTo(Windows.UI.Xaml.Navigation.NavigationEventArgs e)
        {
            // This one doesn't work. Probably because of the GridViewItem's animation.
            this.TrappedTextBox.Focus(FocusState.Programmatic);
        }

        private void InputPane_Showing(InputPane sender, InputPaneVisibilityEventArgs args)
        {
            this.ShowButton.IsEnabled = false;
            this.HideButton.IsEnabled = true;
        }

        private void InputPane_Hiding(InputPane sender, InputPaneVisibilityEventArgs args)
        {
            this.ShowButton.IsEnabled = true;
            this.HideButton.IsEnabled = false;
        }


        private void ShowKeyBoard_Click(object sender, RoutedEventArgs e)
        {
            this.KeyboardOpener.Focus(FocusState.Programmatic);
        }

        private void HideKeyboard_Click(object sender, RoutedEventArgs e)
        {
            // This would also work without any code: Button is not in the keep-the-keyboard-open list.
            this.KeyboardCloser.Focus(FocusState.Programmatic);
        }

        private void GridViewItem_Tapped(object sender, Windows.UI.Xaml.Input.TappedRoutedEventArgs e)
        {
            // Uncomment this line to close the keyboard by tapping the GridViewItem.
            // this.KeyboardCloser.Focus(FocusState.Programmatic);
        }
    }
}
